aboutsummaryrefslogtreecommitdiff
path: root/ML_WaveToy/src
diff options
context:
space:
mode:
authorErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
committerErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
commitd178c81a0cb1da927bfd7d0bb64043d9484b353b (patch)
tree2a48ab29ef4a72dc1d1ae60e00cd7c0f231ae823 /ML_WaveToy/src
parent87fa6dcf3ff19d937313d20cca8f9e2bca1d4aec (diff)
Allow 4 RHS time levels.
Re-generate code.
Diffstat (limited to 'ML_WaveToy/src')
-rw-r--r--ML_WaveToy/src/Boundaries.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/ML_WaveToy/src/Boundaries.c b/ML_WaveToy/src/Boundaries.c
index 086626f..995ed75 100644
--- a/ML_WaveToy/src/Boundaries.c
+++ b/ML_WaveToy/src/Boundaries.c
@@ -25,7 +25,7 @@ void ML_WaveToy_CheckBoundaries(CCTK_ARGUMENTS)
return;
}
-void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
+void ML_WaveToy_SelectBoundConds(CCTK_ARGUMENTS)
{
DECLARE_CCTK_ARGUMENTS;
DECLARE_CCTK_PARAMETERS;
@@ -78,7 +78,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -97,7 +97,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -116,7 +116,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -135,7 +135,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -154,7 +154,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -171,7 +171,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_WT_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -188,7 +188,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_rho_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -205,7 +205,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_u_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -78,7 +78,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -97,7 +97,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -116,7 +116,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -135,7 +135,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -154,7 +154,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_rho_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_WT_rho_bound = -1;
if (handle_WT_rho_bound < 0) handle_WT_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -171,7 +171,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(WT_u_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_WT_u_bound = -1;
if (handle_WT_u_bound < 0) handle_WT_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -188,7 +188,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(rho_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_rho_bound = -1;
if (handle_rho_bound < 0) handle_rho_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -205,7 +205,7 @@ void ML_WaveToy_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(u_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_u_bound = -1;
if (handle_u_bound < 0) handle_u_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);